@@ -1,4 +1,4 @@
-// 13jan23 Software Lab. Alexander Burger
+// 22apr23 Software Lab. Alexander Burger
 
 #include "pico.h"
 
@@ -659,7 +659,7 @@ ffi *ffiPrep(char *lib, char *fun, uint64_t lst) {
       x  = car(y);
       if (num(x))
          p->args[i] = &ffi_type_sint64;
-      else if (sym(x))
+      else if (sym(x) || car(x) == (uint64_t)(SymTab + T))
          p->args[i] = &ffi_type_pointer;
       else if (cnt(cdr(x)))
          p->args[i] = (cdr(x) & 8)? &ffi_type_float : &ffi_type_double;
@@ -738,6 +738,14 @@ void *arg(void *p) {
    return p;
 }
 
+// Util
+int chance(int64_t m) {
+   static uint32_t seed = 1664525;
+
+   return (((seed = seed * 1664525 + 1) >> 16) & (int32_t)m) != 0;
+}
+
+
 // Case mappings from the GNU Kaffe Project
 #define CHAR_UPPERCASE  1
 #define CHAR_LOWERCASE  2
